

# $Id: Motors.pm,v 1.1 2004/09/25 21:19:00 Daddy Exp $



=head1 NAME



WWW::Search::Ebay::Motors - backend for searching eBay Motors



=head1 SYNOPSIS



  use WWW::Search;

  my $oSearch = new WWW::Search('Ebay::Motors');

  my $sQuery = WWW::Search::escape_query("Buick Star Wars");

  $oSearch->native_query($sQuery);

  while (my $oResult = $oSearch->next_result())

    { print $oResult->url, "\n"; }



=head1 DESCRIPTION



This class is a Ebay Motors specialization of WWW::Search.

It handles making and interpreting Ebay searches

F<http://www.ebay.com>.



This class exports no public interface; all interaction should

be done through L<WWW::Search> objects.



=head1 NOTES



Same as L<WWW::Search::Ebay>.



=head1 OPTIONS



Same as L<WWW::Search::Ebay>.



=head1 SEE ALSO



To make new back-ends, see L<WWW::Search>.



=head1 CAVEATS



=head1 BUGS



Please tell the author if you find any!



=head1 AUTHOR



C<WWW::Search::Ebay::Motors> was written by Martin Thurn

(mthurn@cpan.org).



C<WWW::Search::Ebay::Motors> is maintained by Martin Thurn

(mthurn@cpan.org).



=head1 LEGALESE



THIS SOFTWARE IS PROVIDED "AS IS" AND WITHOUT ANY EXPRESS OR IMPLIED

WARRANTIES, INCLUDING, WITHOUT LIMITATION, THE IMPLIED WARRANTIES OF

MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.



=cut



#####################################################################



package WWW::Search::Ebay::Motors;



use Carp;

use Data::Dumper;

use WWW::Search::Ebay;



use strict;

use vars qw( @ISA $VERSION $MAINTAINER );



@ISA = qw( WWW::Search::Ebay );

$VERSION = do { my @r = (q$Revision: 1.1 $ =~ /\d+/g); sprintf "%d."."%03d" x $#r, @r };

$MAINTAINER = 'Martin Thurn <mthurn@cpan.org>';



sub native_setup_search

  {

  my ($self, $native_query, $rhOptsArg) = @_;

  $rhOptsArg ||= {};

  unless (ref($rhOptsArg) eq 'HASH')

    {

    carp " --- second argument to native_setup_search should be hashref, not arrayref";

    return undef;

    } # unless

  $rhOptsArg->{search_host} = 'http://motors.search.ebay.com';

  return $self->SUPER::native_setup_search($native_query, $rhOptsArg);

  } # native_setup_search



1;



__END__

